==> openkb-1.0.18.tgz: package/locales/en.js <==
{
	"Toggle navigation": "Toggle navigation",
	"Users": "Users",
	"New": "New",
	"Edit": "Edit",
	"My account": "My account",
	"Article": "Article",
	"Settings": "Settings",
	"Files": "Files",
	"Export": "Export",
	"Cleanup files": "Cleanup files",
	"Logout": "Logout",
	"Powered by": "Powered by",
	"Home": "Home",
	"Articles": "Articles",
	"Filter articles": "Filter articles",
	"Filter": "Filter",
	"Reset": "Reset",
	"All": "All",
	"Published": "Published",
	"Recent": "Recent",
	"Are you sure you want to delete this article?": "Are you sure you want to delete this article?",
	"Search": "Search",
	"Featured articles": "Featured articles",
	"Top articles": "Top articles",
	"Suggest": "Suggest",
	"Login": "Login",
	"Please sign in": "Please sign in",
	"email address": "email address",
	"Password": "Password",
	"Sign in": "Sign in",
	"Website": "Website",
	"Display": "Display",
	"Update": "Update",
	"Website title": "Website title",
	"The title of your website": "The title of your website",
	"Website description": "Website description",
	"A short website description when listing the homepage URL in search engines": "A short website description when listing the homepage URL in search engines",
	"Show website logo": "Show website logo",
	"true": "true",
	"false": "false",
	"Controls whether to show the 'Website title' text or a logo located: '/public/logo.png' (by default)": "Controls whether to show the 'Website title' text or a logo located: '/public/logo.png' (by default)",
	"Website context/base URL": "Website context/base URL",
	"Allows for the website to be run from a non root path. Eg: http://127.0.0.1:4444/openkb/": "Allows for the website to be run from a non root path. Eg: http://127.0.0.1:4444/openkb/",
	"Allow API access": "Allow API access",
	"Whether to allow API access to insert articles - See documentation for further information": "Whether to allow API access to insert articles - See documentation for further information",
	"API access token": "API access token",
	"Requires 'Allow API access' to be set to 'true'. The value is the access token required to access the public API. Please set to a hard to guess value": "Requires 'Allow API access' to be set to 'true'. The value is the access token required to access the public API. Please set to a hard to guess value",
	"Password protect": "Password protect",
	"Setting to 'true' will require a user to login before viewing any pages": "Setting to 'true' will require a user to login before viewing any pages",
	"Index article body": "Index article body",
	"Whether to add the body of your articles to the search index (requires restart)": "Whether to add the body of your articles to the search index (requires restart)",
	"Select a theme": "Select a theme",
	"The theme to use for public facing pages. Leave blank for default": "The theme to use for public facing pages. Leave blank for default",
	"Show logon link": "Show logon link",
	"Whether to show/hide the logon link in the top right of screen": "Whether to show/hide the logon link in the top right of screen",
	"Date format": "Date format",
	"Sets the global date formatting. Uses moment.js date formatting, see more here: http://momentjs.com/docs/#/displaying": "Sets the global date formatting. Uses moment.js date formatting, see more here: http://momentjs.com/docs/#/displaying",
	"Article suggestions allowed": "Article suggestions allowed",
	"If enabled non authenticated users can submit article suggestions for approval": "If enabled non authenticated users can submit article suggestions for approval",
	"Google analytics code": "Google analytics code",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags": "Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags",
	"Allow voting": "Allow voting",
	"Whether to allow users to vote on an article": "Whether to allow users to vote on an article",
	"Show article meta data": "Show article meta data",
	"Whether to show article meta data including published date, last updated date, author etc": "Whether to show article meta data including published date, last updated date, author etc",
	"Show author email": "Show author email",
	"Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true": "Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true",
	"Article links open new page": "Article links open new page",
	"Controls whether links within articles open a new page (tab)": "Controls whether links within articles open a new page (tab)",
	"Add header anchors": "Add header anchors",
	"Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles": "Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles",
	"Enable editor spellchecker": "Enable editor spellchecker",
	"Controls whether to enable the editor spellchecker": "Controls whether to enable the editor spellchecker",
	"Allow article versioning": "Allow article versioning",
	"Whether to track article versions with each save of the editor": "Whether to track article versions with each save of the editor",
	"Number of top articles shown on homepage": "Number of top articles shown on homepage",
	"Sets the number of results shown on the home page": "Sets the number of results shown on the home page",
	"Show published date": "Show published date",
	"Shows the published date next to the results on the homepage and search": "Shows the published date next to the results on the homepage and search",
	"Show view count": "Show view count",
	"Shows the view count next to the results on the homepage and search": "Shows the view count next to the results on the homepage and search",
	"Update view count when logged in": "Update view count when logged in",
	"Updates the view count also when users are logged in": "Updates the view count also when users are logged in",
	"Show featured articles": "Show featured articles",
	"Whether to show any articles set to featured in a sidebar": "Whether to show any articles set to featured in a sidebar",
	"Show featured articles when viewing article": "Show featured articles when viewing article",
	"Whether to show any articles set to featured in a sidebar when viewing an article": "Whether to show any articles set to featured in a sidebar when viewing an article",
	"Featured article count": "Featured article count",
	"The number of featured articles shown": "The number of featured articles shown",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the <script> tags": "Adds Google Analytics to public facing pages. Include the entire code from Google including the <script> tags",
	"New user": "New user",
	"Users name": "Users name",
	"User email": "User email",
	"User password": "User password",
	"Password confirm": "Password confirm",
	"Create": "Create",
	"A user with that email address already exists": "A user with that email address already exists",
	"User": "User",
	"Role": "Role",
	"Admin": "Admin",
	"Are you sure you want to delete?": "Are you sure you want to delete?",
	"User edit": "User edit",
	"Password values do not match": "Password values do not match",
	"Date": "Date",
	"View count": "View count"
}

==> openkb-1.0.19.tgz: package/locales/en.js <==
{
	"Toggle navigation": "Toggle navigation",
	"Users": "Users",
	"New": "New",
	"Edit": "Edit",
	"My account": "My account",
	"Article": "Article",
	"Settings": "Settings",
	"Files": "Files",
	"Export": "Export",
	"Cleanup files": "Cleanup files",
	"Logout": "Logout",
	"Powered by": "Powered by",
	"Home": "Home",
	"Articles": "Articles",
	"Filter articles": "Filter articles",
	"Filter": "Filter",
	"Reset": "Reset",
	"All": "All",
	"Published": "Published",
	"Recent": "Recent",
	"Are you sure you want to delete this article?": "Are you sure you want to delete this article?",
	"Search": "Search",
	"Featured articles": "Featured articles",
	"Top articles": "Top articles",
	"Suggest": "Suggest",
	"Login": "Login",
	"Please sign in": "Please sign in",
	"email address": "email address",
	"Password": "Password",
	"Sign in": "Sign in",
	"Website": "Website",
	"Display": "Display",
	"Update": "Update",
	"Website title": "Website title",
	"The title of your website": "The title of your website",
	"Website description": "Website description",
	"A short website description when listing the homepage URL in search engines": "A short website description when listing the homepage URL in search engines",
	"Show website logo": "Show website logo",
	"true": "true",
	"false": "false",
	"Controls whether to show the 'Website title' text or a logo located: '/public/logo.png' (by default)": "Controls whether to show the 'Website title' text or a logo located: '/public/logo.png' (by default)",
	"Website context/base URL": "Website context/base URL",
	"Allows for the website to be run from a non root path. Eg: http://127.0.0.1:4444/openkb/": "Allows for the website to be run from a non root path. Eg: http://127.0.0.1:4444/openkb/",
	"Allow API access": "Allow API access",
	"Whether to allow API access to insert articles - See documentation for further information": "Whether to allow API access to insert articles - See documentation for further information",
	"API access token": "API access token",
	"Requires 'Allow API access' to be set to 'true'. The value is the access token required to access the public API. Please set to a hard to guess value": "Requires 'Allow API access' to be set to 'true'. The value is the access token required to access the public API. Please set to a hard to guess value",
	"Password protect": "Password protect",
	"Setting to 'true' will require a user to login before viewing any pages": "Setting to 'true' will require a user to login before viewing any pages",
	"Index article body": "Index article body",
	"Whether to add the body of your articles to the search index (requires restart)": "Whether to add the body of your articles to the search index (requires restart)",
	"Select a theme": "Select a theme",
	"The theme to use for public facing pages. Leave blank for default": "The theme to use for public facing pages. Leave blank for default",
	"Show logon link": "Show logon link",
	"Whether to show/hide the logon link in the top right of screen": "Whether to show/hide the logon link in the top right of screen",
	"Date format": "Date format",
	"Sets the global date formatting. Uses moment.js date formatting, see more here: http://momentjs.com/docs/#/displaying": "Sets the global date formatting. Uses moment.js date formatting, see more here: http://momentjs.com/docs/#/displaying",
	"Article suggestions allowed": "Article suggestions allowed",
	"If enabled non authenticated users can submit article suggestions for approval": "If enabled non authenticated users can submit article suggestions for approval",
	"Google analytics code": "Google analytics code",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags": "Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags",
	"Allow voting": "Allow voting",
	"Whether to allow users to vote on an article": "Whether to allow users to vote on an article",
	"Show article meta data": "Show article meta data",
	"Whether to show article meta data including published date, last updated date, author etc": "Whether to show article meta data including published date, last updated date, author etc",
	"Show author email": "Show author email",
	"Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true": "Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true",
	"Article links open new page": "Article links open new page",
	"Controls whether links within articles open a new page (tab)": "Controls whether links within articles open a new page (tab)",
	"Add header anchors": "Add header anchors",
	"Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles": "Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles",
	"Enable editor spellchecker": "Enable editor spellchecker",
	"Controls whether to enable the editor spellchecker": "Controls whether to enable the editor spellchecker",
	"Allow article versioning": "Allow article versioning",
	"Whether to track article versions with each save of the editor": "Whether to track article versions with each save of the editor",
	"Number of top articles shown on homepage": "Number of top articles shown on homepage",
	"Sets the number of results shown on the home page": "Sets the number of results shown on the home page",
	"Show published date": "Show published date",
	"Shows the published date next to the results on the homepage and search": "Shows the published date next to the results on the homepage and search",
	"Show view count": "Show view count",
	"Shows the view count next to the results on the homepage and search": "Shows the view count next to the results on the homepage and search",
	"Update view count when logged in": "Update view count when logged in",
	"Updates the view count also when users are logged in": "Updates the view count also when users are logged in",
	"Show featured articles": "Show featured articles",
	"Whether to show any articles set to featured in a sidebar": "Whether to show any articles set to featured in a sidebar",
	"Show featured articles when viewing article": "Show featured articles when viewing article",
	"Whether to show any articles set to featured in a sidebar when viewing an article": "Whether to show any articles set to featured in a sidebar when viewing an article",
	"Featured article count": "Featured article count",
	"The number of featured articles shown": "The number of featured articles shown",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the <script> tags": "Adds Google Analytics to public facing pages. Include the entire code from Google including the <script> tags",
	"New user": "New user",
	"Users name": "Users name",
	"User email": "User email",
	"User password": "User password",
	"Password confirm": "Password confirm",
	"Create": "Create",
	"A user with that email address already exists": "A user with that email address already exists",
	"User": "User",
	"Role": "Role",
	"Admin": "Admin",
	"Are you sure you want to delete?": "Are you sure you want to delete?",
	"User edit": "User edit",
	"Password values do not match": "Password values do not match",
	"Date": "Date",
	"View count": "View count",
	"Article title": "Article title",
	"Status": "Status",
	"Draft": "Draft",
	"Insert": "Insert",
	"Article body": "Article body",
	"Preview": "Preview",
	"comma, separated, list": "comma, separated, list",
	"Permalink for the article": "Permalink for the article",
	"Validate": "Validate",
	"Generate": "Generate",
	"Slug from title": "Slug from title",
	"Search the knowledge base": "Search the knowledge base",
	"Was this article helpful?": "Was this article helpful?",
	"Votes": "Votes",
	"Article details": "Article details",
	"Published date": "Published date",
	"Last updated": "Last updated",
	"Share article": "Share article",
	"Author": "Author",
	"keyword": "keyword",
	"permalink": "permalink",
	"Delete": "Delete",
	"Reset views": "Reset views",
	"Reset votes": "Reset votes",
	"Featured article": "Featured article",
	"SEO title": "SEO title",
	"SEO description": "SEO description",
	"Controls whether to show the \"Website title\" text or a logo located: \"/public/logo.png\" (by default)": "Controls whether to show the \"Website title\" text or a logo located: \"/public/logo.png\" (by default)",
	"Requires \"Allow API access\" to be set to \"true\". The value is the access token required to access the public API. Please set to a hard to guess value": "Requires \"Allow API access\" to be set to \"true\". The value is the access token required to access the public API. Please set to a hard to guess value",
	"Setting to \"true\" will require a user to login before viewing any pages": "Setting to \"true\" will require a user to login before viewing any pages",
	"Controls whether the authors email address is displayed in the meta. Requires \"Show article meta data\" to be true": "Controls whether the authors email address is displayed in the meta. Requires \"Show article meta data\" to be true",
	"Not Found": "Not Found",
	"Select file": "Select file",
	"Upload directory": "Upload directory",
	"Upload file": "Upload file",
	"Tip": "Tip",
	"To insert an image right click the link, copy the link address and add it to your Markdown": "To insert an image right click the link, copy the link address and add it to your Markdown",
	"New directory": "New directory",
	"Multiple directories can be created using a \"/\" separator": "Multiple directories can be created using a \"/\" separator",
	"Article successfully deleted": "Article successfully deleted",
	"Keywords": "Keywords",
	"Import": "Import",
	"New article successfully created": "New article successfully created",
	"Successfully saved": "Successfully saved",
	"Permalink": "Permalink",
	"Access denied. Check password and try again.": "Access denied. Check password and try again.",
	"Select a language": "Select a language",
	"The language to use for public facing pages. Leave blank for default (English)": "The language to use for public facing pages. Leave blank for default (English)",
	"Settings successfully updated.": "Settings successfully updated.",
	"Results for": "Results for",
	"No results found": "No results found",
	"Access denied": "Access denied",
	"User account inserted": "User account inserted"
}
